@@ -1,20 +1,16 @@
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-from __future__ import unicode_literals
-
 import unittest
 
+from unittest import mock
+
 try:
     from kazoo.exceptions import NoNodeError
 except ImportError:
     raise unittest.SkipTest("kazoo is not installed")
 
-from baseplate.live_data.zookeeper import zookeeper_client_from_config
-from baseplate.secrets import SecretsStore
+from baseplate.lib.live_data.zookeeper import zookeeper_client_from_config
+from baseplate.lib.secrets import SecretsStore
 
 from .. import get_endpoint_or_skip_container
-from ... import mock
 
 zookeeper_endpoint = get_endpoint_or_skip_container("zookeeper", 2181)
 
@@ -22,9 +18,9 @@ zookeeper_endpoint = get_endpoint_or_skip_container("zookeeper", 2181)
 class ZooKeeperTests(unittest.TestCase):
     def test_create_client_no_secrets(self):
         secrets = mock.Mock(spec=SecretsStore)
-        client = zookeeper_client_from_config(secrets, {
-            "zookeeper.hosts": "%s:%d" % zookeeper_endpoint.address,
-        })
+        client = zookeeper_client_from_config(
+            secrets, {"zookeeper.hosts": "%s:%d" % zookeeper_endpoint.address}
+        )
 
         client.start()
 
@@ -37,10 +33,13 @@ class ZooKeeperTests(unittest.TestCase):
         secrets = mock.Mock(spec=SecretsStore)
         secrets.get_simple.return_value = b"myzkuser:hunter2"
 
-        client = zookeeper_client_from_config(secrets, {
-            "zookeeper.hosts": "%s:%d" % zookeeper_endpoint.address,
-            "zookeeper.credentials": "secret/zk-user",
-        })
+        client = zookeeper_client_from_config(
+            secrets,
+            {
+                "zookeeper.hosts": "%s:%d" % zookeeper_endpoint.address,
+                "zookeeper.credentials": "secret/zk-user",
+            },
+        )
 
         client.start()
         with self.assertRaises(NoNodeError):
@@ -48,4 +47,4 @@ class ZooKeeperTests(unittest.TestCase):
         client.stop()
 
         secrets.get_simple.assert_called_with("secret/zk-user")
-        self.assertEqual(client.auth_data, [("digest", "myzkuser:hunter2")])
+        self.assertEqual(list(client.auth_data), [("digest", "myzkuser:hunter2")])
