@@ -1,40 +1,27 @@
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
-# webtest doesn't play well with unicode literals for headers on py2 :(
-#from __future__ import unicode_literals
-
+import base64
 import unittest
-import jwt
+
+from unittest import mock
+
+from pyramid.response import Response
 
 from baseplate import Baseplate
-from baseplate.core import (
-    BaseplateObserver,
-    EdgeRequestContextFactory,
-    NoAuthenticationError,
-    ServerSpanObserver,
-)
-from baseplate.file_watcher import FileWatcher
-from baseplate.secrets import store
+from baseplate import BaseplateObserver
+from baseplate import ServerSpanObserver
+
+from . import FakeEdgeContextFactory
+
 
 try:
     import webtest
 
-    from baseplate.integration.pyramid import (
-        BaseplateConfigurator,
-        ServerSpanInitialized,
-    )
+    from baseplate.frameworks.pyramid import BaseplateConfigurator
+    from baseplate.frameworks.pyramid import ServerSpanInitialized
+    from baseplate.frameworks.pyramid import StaticTrustHandler
     from pyramid.config import Configurator
 except ImportError:
     raise unittest.SkipTest("pyramid/webtest is not installed")
 
-from .. import (
-    mock,
-    AUTH_TOKEN_PUBLIC_KEY,
-    SERIALIZED_EDGECONTEXT_WITH_VALID_AUTH,
-)
-
 
 class TestException(Exception):
     pass
@@ -62,6 +49,14 @@ def example_application(request):
     if "exception_view_exception" in request.params:
         raise ControlFlowException2()
 
+    if "stream" in request.params:
+
+        def make_iter():
+            yield b"foo"
+            yield b"bar"
+
+        return Response(status_code=200, app_iter=make_iter())
+
     return {"test": "success"}
 
 
@@ -74,11 +69,10 @@ def render_bad_exception_view(request):
 
 
 def local_tracing_within_context(request):
-    with request.trace.make_child('local-req',
-                                  local=True,
-                                  component_name='in-context'):
+    with request.span.make_child("local-req", local=True, component_name="in-context"):
         pass
-    return {'trace': 'success'}
+    return {"trace": "success"}
+
 
 class ConfiguratorTests(unittest.TestCase):
     def setUp(self):
@@ -86,52 +80,32 @@ class ConfiguratorTests(unittest.TestCase):
         configurator.add_route("example", "/example", request_method="GET")
         configurator.add_route("trace_context", "/trace_context", request_method="GET")
 
-        configurator.add_view(
-            example_application, route_name="example", renderer="json")
+        configurator.add_view(example_application, route_name="example", renderer="json")
 
         configurator.add_view(
-            local_tracing_within_context, route_name="trace_context", renderer="json")
-
-        configurator.add_view(
-            render_exception_view,
-            context=ControlFlowException,
-            renderer="json",
+            local_tracing_within_context, route_name="trace_context", renderer="json"
         )
 
-        configurator.add_view(
-            render_bad_exception_view,
-            context=ControlFlowException2,
-            renderer="json",
-        )
+        configurator.add_view(render_exception_view, context=ControlFlowException, renderer="json")
 
-        mock_filewatcher = mock.Mock(spec=FileWatcher)
-        mock_filewatcher.get_data.return_value = {
-            "secrets": {
-                "secret/authentication/public-key": {
-                    "type": "versioned",
-                    "current": AUTH_TOKEN_PUBLIC_KEY,
-                },
-            },
-            "vault": {
-                "token": "test",
-                "url": "http://vault.example.com:8200/",
-            }
-        }
-        secrets = store.SecretsStore("/secrets")
-        secrets._filewatcher = mock_filewatcher
+        configurator.add_view(
+            render_bad_exception_view, context=ControlFlowException2, renderer="json"
+        )
 
         self.observer = mock.Mock(spec=BaseplateObserver)
         self.server_observer = mock.Mock(spec=ServerSpanObserver)
+
         def _register_mock(context, server_span):
             server_span.register(self.server_observer)
+
         self.observer.on_server_span_created.side_effect = _register_mock
 
         self.baseplate = Baseplate()
         self.baseplate.register(self.observer)
         self.baseplate_configurator = BaseplateConfigurator(
             self.baseplate,
-            trust_trace_headers=True,
-            edge_context_factory=EdgeRequestContextFactory(secrets),
+            edge_context_factory=FakeEdgeContextFactory(),
+            header_trust_handler=StaticTrustHandler(trust_headers=True),
         )
         configurator.include(self.baseplate_configurator.includeme)
         self.context_init_event_subscriber = mock.Mock()
@@ -147,85 +121,69 @@ class ConfiguratorTests(unittest.TestCase):
         self.assertEqual(self.observer.on_server_span_created.call_count, 1)
 
         context, server_span = self.observer.on_server_span_created.call_args[0]
-        self.assertEqual(server_span.trace_id, 1234)
+        self.assertEqual(server_span.trace_id, "1234")
         self.assertEqual(server_span.parent_id, None)
-        self.assertEqual(server_span.id, 1234)
+        self.assertEqual(server_span.id, "1234")
 
         self.assertTrue(self.server_observer.on_start.called)
         self.assertTrue(self.server_observer.on_finish.called)
         self.assertTrue(self.context_init_event_subscriber.called)
 
     def test_trace_headers(self):
-        self.test_app.get("/example", headers={
-            "X-Trace": "1234",
-            "X-Parent": "2345",
-            "X-Span": "3456",
-            "X-Sampled": "1",
-            "X-Flags": "1",
-        })
+        self.test_app.get(
+            "/example",
+            headers={
+                "X-Trace": "1234",
+                "X-Edge-Request": base64.b64encode(FakeEdgeContextFactory.RAW_BYTES).decode(),
+                "X-Parent": "2345",
+                "X-Span": "3456",
+                "X-Sampled": "1",
+                "X-Flags": "1",
+            },
+        )
 
         self.assertEqual(self.observer.on_server_span_created.call_count, 1)
 
         context, server_span = self.observer.on_server_span_created.call_args[0]
-        self.assertEqual(server_span.trace_id, 1234)
-        self.assertEqual(server_span.parent_id, 2345)
-        self.assertEqual(server_span.id, 3456)
+        self.assertEqual(server_span.trace_id, "1234")
+        self.assertEqual(server_span.parent_id, "2345")
+        self.assertEqual(server_span.id, "3456")
         self.assertEqual(server_span.sampled, True)
         self.assertEqual(server_span.flags, 1)
 
-        with self.assertRaises(NoAuthenticationError):
-            context.request_context.user.id
-
-        self.assertTrue(self.server_observer.on_start.called)
-        self.assertTrue(self.server_observer.on_finish.called)
-        self.assertTrue(self.context_init_event_subscriber.called)
-
-    def test_b3_trace_headers(self):
-        self.test_app.get("/example", headers={
-            "X-B3-TraceId": "1234",
-            "X-B3-ParentSpanId": "2345",
-            "X-B3-SpanId": "3456",
-            "X-B3-Sampled": "1",
-            "X-B3-Flags": "1",
-        })
-
-        self.assertEqual(self.observer.on_server_span_created.call_count, 1)
-
-        context, server_span = self.observer.on_server_span_created.call_args[0]
-        self.assertEqual(server_span.trace_id, 1234)
-        self.assertEqual(server_span.parent_id, 2345)
-        self.assertEqual(server_span.id, 3456)
-        self.assertEqual(server_span.sampled, True)
-        self.assertEqual(server_span.flags, 1)
-
-        with self.assertRaises(NoAuthenticationError):
-            context.request_context.user.id
-
         self.assertTrue(self.server_observer.on_start.called)
         self.assertTrue(self.server_observer.on_finish.called)
         self.assertTrue(self.context_init_event_subscriber.called)
 
     def test_edge_request_headers(self):
-        self.test_app.get("/example", headers={
-            "X-Trace": "1234",
-            "X-Edge-Request": SERIALIZED_EDGECONTEXT_WITH_VALID_AUTH,
-            "X-Parent": "2345",
-            "X-Span": "3456",
-            "X-Sampled": "1",
-            "X-Flags": "1",
-        })
+        self.test_app.get(
+            "/example",
+            headers={
+                "X-Trace": "1234",
+                "X-Edge-Request": base64.b64encode(FakeEdgeContextFactory.RAW_BYTES).decode(),
+                "X-Parent": "2345",
+                "X-Span": "3456",
+                "X-Sampled": "1",
+                "X-Flags": "1",
+            },
+        )
         context, _ = self.observer.on_server_span_created.call_args[0]
-        try:
-            self.assertEqual(context.request_context.user.id, "t2_example")
-            self.assertEqual(context.request_context.user.roles, set())
-            self.assertEqual(context.request_context.user.is_logged_in, True)
-            self.assertEqual(context.request_context.user.loid, "t2_deadbeef")
-            self.assertEqual(context.request_context.user.cookie_created_ms, 100000)
-            self.assertEqual(context.request_context.oauth_client.id, None)
-            self.assertFalse(context.request_context.oauth_client.is_type("third_party"))
-            self.assertEqual(context.request_context.session.id, "beefdead")
-        except jwt.exceptions.InvalidAlgorithmError:
-            raise unittest.SkipTest("cryptography is not installed")
+        assert context.edge_context == FakeEdgeContextFactory.DECODED_CONTEXT
+
+    def test_empty_edge_request_headers(self):
+        self.test_app.get(
+            "/example",
+            headers={
+                "X-Trace": "1234",
+                "X-Edge-Request": "",
+                "X-Parent": "2345",
+                "X-Span": "3456",
+                "X-Sampled": "1",
+                "X-Flags": "1",
+            },
+        )
+        context, _ = self.observer.on_server_span_created.call_args[0]
+        self.assertEqual(context.raw_edge_context, b"")
 
     def test_not_found(self):
         self.test_app.get("/nope", status=404)
@@ -264,23 +222,56 @@ class ConfiguratorTests(unittest.TestCase):
 
     @mock.patch("random.getrandbits")
     def test_distrust_headers(self, getrandbits):
-        getrandbits.return_value = 1234
+        getrandbits.return_value = 9999
         self.baseplate_configurator.header_trust_handler.trust_headers = False
 
-        self.test_app.get("/example", headers={
-            "X-Trace": "1234",
-            "X-Parent": "2345",
-            "X-Span": "3456",
-        })
+        self.test_app.get(
+            "/example", headers={"X-Trace": "1234", "X-Parent": "2345", "X-Span": "3456"}
+        )
 
         context, server_span = self.observer.on_server_span_created.call_args[0]
-        self.assertEqual(server_span.trace_id, getrandbits.return_value)
+        self.assertEqual(server_span.trace_id, str(getrandbits.return_value))
         self.assertEqual(server_span.parent_id, None)
-        self.assertEqual(server_span.id, getrandbits.return_value)
+        self.assertEqual(server_span.id, str(getrandbits.return_value))
 
     def test_local_trace_in_context(self):
-        self.test_app.get('/trace_context')
+        self.test_app.get("/trace_context")
         self.assertEqual(self.server_observer.on_child_span_created.call_count, 1)
         child_span = self.server_observer.on_child_span_created.call_args[0][0]
         context, server_span = self.observer.on_server_span_created.call_args[0]
         self.assertNotEqual(child_span.context, context)
+
+    def test_streaming_response(self):
+        class StreamingTestResponse(webtest.TestResponse):
+            def decode_content(self):
+                # keep your grubby hands off the app_iter, webtest!!!!
+                pass
+
+            @property
+            def body(self):
+                # seriously
+                pass
+
+        class StreamingTestRequest(webtest.TestRequest):
+            ResponseClass = StreamingTestResponse
+
+        self.test_app.RequestClass = StreamingTestRequest
+
+        response = self.test_app.get("/example?stream")
+
+        # ok, we've returned from the wsgi app but the iterator's not done
+        # so... we should have started the span but not finished it yet
+        self.assertTrue(self.server_observer.on_start.called)
+        self.assertFalse(self.server_observer.on_finish.called)
+
+        self.assertEqual(b"foo", next(response.app_iter))
+        self.assertFalse(self.server_observer.on_finish.called)
+
+        self.assertEqual(b"bar", next(response.app_iter))
+        self.assertFalse(self.server_observer.on_finish.called)
+
+        with self.assertRaises(StopIteration):
+            next(response.app_iter)
+        self.assertTrue(self.server_observer.on_finish.called)
+
+        response.app_iter.close()
