@@ -1,8 +1,3 @@
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-from __future__ import unicode_literals
-
 import unittest
 
 try:
@@ -12,15 +7,15 @@ try:
 except ImportError:
     raise unittest.SkipTest("sqlalchemy is not installed")
 
-from baseplate.context.sqlalchemy import (
+from baseplate.clients.sqlalchemy import (
     engine_from_config,
     SQLAlchemyEngineContextFactory,
+    SQLAlchemySession,
     SQLAlchemySessionContextFactory,
 )
-from baseplate.core import Baseplate
+from baseplate import Baseplate
 
 from . import TestBaseplateObserver
-from .. import mock
 
 
 Base = declarative_base()
@@ -45,7 +40,7 @@ class SQLAlchemyEngineTests(unittest.TestCase):
         baseplate.register(self.baseplate_observer)
         baseplate.add_to_context("db", factory)
 
-        self.context = mock.Mock()
+        self.context = baseplate.make_context_object()
         self.server_span = baseplate.make_server_span(self.context, "test")
 
     def test_simple_query(self):
@@ -59,9 +54,23 @@ class SQLAlchemyEngineTests(unittest.TestCase):
         self.assertIsNone(span_observer.on_finish_exc_info)
         span_observer.assert_tag("statement", "SELECT * FROM test;")
 
+    def test_very_long_query(self):
+        with self.server_span:
+            self.server_span.context.db.execute("SELECT *" + (" " * 1024) + "FROM test;")
+
+        server_span_observer = self.baseplate_observer.get_only_child()
+        span_observer = server_span_observer.get_only_child()
+        self.assertTrue(span_observer.on_start_called)
+        self.assertTrue(span_observer.on_finish_called)
+        self.assertIsNone(span_observer.on_finish_exc_info)
+        tag = span_observer.tags["statement"]
+        assert len(tag) <= 1024
+
     def test_nested_local_span(self):
         with self.server_span:
-            with self.server_span.make_child("local", local=True, component_name="example") as local:
+            with self.server_span.make_child(
+                "local", local=True, component_name="example"
+            ) as local:
                 local.context.db.execute("SELECT * FROM test;")
 
         server_span_observer = self.baseplate_observer.get_only_child()
@@ -96,7 +105,7 @@ class SQLAlchemySessionTests(unittest.TestCase):
         baseplate.register(self.baseplate_observer)
         baseplate.add_to_context("db", factory)
 
-        self.context = mock.Mock()
+        self.context = baseplate.make_context_object()
         self.server_span = baseplate.make_server_span(self.context, "test")
 
     def test_simple_session(self):
@@ -110,3 +119,13 @@ class SQLAlchemySessionTests(unittest.TestCase):
         self.assertTrue(span_observer.on_start_called)
         self.assertTrue(span_observer.on_finish_called)
         self.assertIsNone(span_observer.on_finish_exc_info)
+
+
+class SQLAlchemySessionConfigTests(unittest.TestCase):
+    def test_simple_config(self):
+        baseplate = Baseplate({"db.url": "sqlite://"})
+        baseplate.configure_context({"db": SQLAlchemySession()})
+
+        context = baseplate.make_context_object()
+        with baseplate.make_server_span(context, "test"):
+            context.db.execute("SELECT 1;")
